@@ -38,7 +38,13 @@ def api_setting(config: Config):
 
 def api_login(config: Config):
     """ deepdriver login """
-    channel = grpc.insecure_channel(config.grpc_host)
+    if config.use_grpc_tls:
+        channel_opts = ()
+        channel_opts += ((
+                             'grpc.ssl_target_name_override', "SERVER_NAME_TO_VERIFY",),)
+        channel = grpc.secure_channel(config.grpc_host, grpc.ssl_channel_credentials(), channel_opts)
+    else:
+        channel = grpc.insecure_channel(config.grpc_host)
     stub = ResourceStub(channel)
     set_stub(stub)
 
