@@ -111,16 +111,19 @@ def post(url: str, data: Dict) -> Dict:
     if rsp.status_code not in [200, 201]:
         logger.debug(f"post({url}) failed({rsp.status_code})")
         try:
-            if json.loads(rsp.text)['result'] == 'fail':
-                if json.loads(rsp.text)['message'] == "INVALID KEY":
-                    logger.error("Invalid Login KEY.")
-                    raise Exception("Invalid Login KEY.")
-                if json.loads(rsp.text)['message'] == "invalid token":
-                    logger.error("Invalid Token.")
-                    raise Exception("Invalid Token.")
-        except Exception as e :
-            pass
-        raise Exception(f"request.post() failed({rsp.text if rsp.text else rsp.status_code})", rsp)
+            json_result = json.loads(rsp.text)  #json 파싱 실패 시
+        except:
+            raise Exception(f"request.post() failed({rsp.text if rsp.text else rsp.status_code})", rsp)
+
+        if ('message' in json_result) and ('result' in json_result) and (json_result['result'] == 'fail'):
+            if json.loads(rsp.text)['message'] == "INVALID KEY":
+                logger.error("Invalid Login KEY.")
+                raise Exception("Invalid Login KEY.")
+            elif json.loads(rsp.text)['message'] == "invalid token":
+                logger.error("Invalid Token.")
+                raise Exception("Invalid Token.")
+            else:
+                raise Exception(f"request.post() failed({rsp.text if rsp.text else rsp.status_code})", rsp)
     return dict(json.loads(rsp.text))
 
 def get_headers():
