@@ -346,7 +346,7 @@ def login(key: str) -> (bool, str):
         # grpc stub 생성
         if use_grpc_tls:
             channel_opt = ()
-            channel_opt += (('grpc.ssl_target_name_override', 'bokchi.com'),)
+            # channel_opt += (('grpc.ssl_target_name_override', 'bokchi.com'),)
             channel = grpc.secure_channel(grpc_url, grpc.ssl_channel_credentials(), channel_opt)
         else:
             channel = grpc.insecure_channel(grpc_url)
